@@ -5,15 +5,6 @@ if [ `uname` == Darwin ]; then
     # The OS X filesystem is case insensitive which causes various problems
     # during the build.
 
-    # For starters conda build cannot unpack the .tar.gz file as it contains
-    # files which differ only in case.
-    # Perform downloading, unpacking and patching manually
-    curl http://legacy.python.org/download/releases/src/python1.0.1.tar.gz \
-        > python1.0.1.tar.gz
-    tar xzf python1.0.1.tar.gz
-    cd python-1.0.1
-    patch -p0 < $RECIPE_DIR/fileobject_getline.patch
-
     # Compile with a no checking of the return type checking, note that
     # CFLAGS cannot be used here.
     export CC="gcc -Wno-return-type"
@@ -27,6 +18,12 @@ if [ `uname` == Darwin ]; then
     mkdir -p $PREFIX/bin
     install -c Python/python $PREFIX/bin/python
 
+    # make libinstall compiles the standard library with the python binary in
+    # the root directory, move it there after making room by removing the
+    # Python directory
+    cp Python/python python_temp
+    rm -rf Python
+    mv python_temp python
     mkdir -p $PREFIX/lib/python
     make libinstall
 fi
